@@ -78,6 +78,7 @@ typedef enum {
 	TOTEM_PLUGIN_TYPE_NARROWSPACE,
 	TOTEM_PLUGIN_TYPE_MULLY,
 	TOTEM_PLUGIN_TYPE_CONE,
+	TOTEM_PLUGIN_TYPE_VEGAS,
 	TOTEM_PLUGIN_TYPE_LAST
 } TotemPluginType;
 
@@ -127,6 +128,7 @@ typedef struct _TotemEmbedded {
 	GList *playlist, *current;
 	guint parser_id;
 	int num_items;
+	gboolean remove_copy;
 
 	/* Open menu item */
 	GAppInfo *app;
@@ -330,7 +332,6 @@ totem_embedded_set_error_logo (TotemEmbedded *embedded,
 	return TRUE;
 }
 
-
 static void
 totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 {
@@ -349,7 +350,7 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 		id = "media-playback-start-symbolic";
 		totem_statusbar_set_text (emb->statusbar, _("Stopped"));
 		totem_statusbar_set_time_and_length (emb->statusbar, 0, 0);
-		totem_time_label_set_time 
+		totem_time_label_set_time
 			(TOTEM_TIME_LABEL (emb->fs->time_label), 0, 0);
 		if (emb->href_uri != NULL && emb->hidden == FALSE) {
 			gdk_window_set_cursor
@@ -394,6 +395,7 @@ totem_embedded_set_logo_by_name (TotemEmbedded *embedded,
 		return;
 
 	bacon_video_widget_set_logo (embedded->bvw, name);
+	bacon_video_widget_set_logo_mode (embedded->bvw, TRUE);
 }
 
 static void
@@ -575,7 +577,7 @@ totem_embedded_set_volume (TotemEmbedded *embedded,
 
 static gboolean
 totem_embedded_launch_player (TotemEmbedded *embedded,
- 			      guint32 user_time)
+			      guint32 user_time)
 {
 	GList *uris = NULL;
 	GdkScreen *screen;
@@ -741,8 +743,8 @@ totem_embedded_set_fullscreen (TotemEmbedded *emb,
 {
 	GValue value = { 0, };
 	GtkAction *fs_action;
-	
-	fs_action = GTK_ACTION (gtk_builder_get_object 
+
+	fs_action = GTK_ACTION (gtk_builder_get_object
 				(emb->menuxml, "fullscreen1"));
 
 	if (totem_fullscreen_is_fullscreen (emb->fs) == fullscreen_enabled)
@@ -916,7 +918,7 @@ totem_embedded_open_playlist_item (TotemEmbedded *emb,
 		}
 
 		if ((eop != FALSE && emb->repeat != FALSE) || (eop == FALSE)) {
-		    	    totem_embedded_play (emb, NULL);
+			    totem_embedded_play (emb, NULL);
 		}
 	}
 
@@ -983,51 +985,56 @@ totem_embedded_set_playlist (TotemEmbedded *emb,
 			     const char *base_uri,
 			     GError **error)
 {
-	char *file_uri;
-	char *tmp_file;
-	GError *err = NULL;
-	GFile *src, *dst;
-	int fd;
-
 	g_message ("Setting the current playlist to %s (uri: %s base: %s)",
 		   path, uri, base_uri);
 
 	totem_embedded_clear_playlist (emb, NULL);
 
-	/* FIXME, we should remove that when we can
-	 * parse from memory or 
-	 * https://bugzilla.gnome.org/show_bug.cgi?id=598702 is fixed */
-	fd = g_file_open_tmp ("totem-browser-plugin-playlist-XXXXXX",
-			      &tmp_file,
-			      &err);
-	if (fd < 0) {
-		g_warning ("Couldn't open temporary file for playlist: %s",
-			   err->message);
-		g_error_free (err);
-		return TRUE;
-	}
-	src = g_file_new_for_path (path);
-	dst = g_file_new_for_path (tmp_file);
-	if (g_file_copy (src, dst, G_FILE_COPY_OVERWRITE | G_FILE_COPY_TARGET_DEFAULT_PERMS, NULL, NULL, NULL, &err) == FALSE) {
-		g_warning ("Failed to copy playlist '%s' to '%s': %s",
-			   path, tmp_file, err->message);
-		g_error_free (err);
+	if (path != NULL && *path != '\0') {
+		char *file_uri;
+		char *tmp_file;
+		GError *err = NULL;
+		GFile *src, *dst;
+		int fd;
+
+		/* FIXME, we should remove that when we can
+		 * parse from memory or
+		 * https://bugzilla.gnome.org/show_bug.cgi?id=598702 is fixed */
+		fd = g_file_open_tmp ("totem-browser-plugin-playlist-XXXXXX",
+				      &tmp_file,
+				      &err);
+		if (fd < 0) {
+			g_warning ("Couldn't open temporary file for playlist: %s",
+				   err->message);
+			g_error_free (err);
+			return TRUE;
+		}
+		src = g_file_new_for_path (path);
+		dst = g_file_new_for_path (tmp_file);
+		if (g_file_copy (src, dst, G_FILE_COPY_OVERWRITE | G_FILE_COPY_TARGET_DEFAULT_PERMS, NULL, NULL, NULL, &err) == FALSE) {
+			g_warning ("Failed to copy playlist '%s' to '%s': %s",
+				   path, tmp_file, err->message);
+			g_error_free (err);
+			g_object_unref (src);
+			g_object_unref (dst);
+			g_free (tmp_file);
+			close (fd);
+			return TRUE;
+		}
+		g_free (tmp_file);
+
+		file_uri = g_file_get_uri (dst);
+
 		g_object_unref (src);
 		g_object_unref (dst);
-		g_free (tmp_file);
 		close (fd);
-		return TRUE;
+
+		emb->remove_copy = TRUE;
+		totem_embedded_set_uri (emb, file_uri, base_uri, NULL, FALSE);
+		g_free (file_uri);
+	} else {
+		totem_embedded_set_uri (emb, uri, base_uri, NULL, FALSE);
 	}
-	g_free (tmp_file);
-
-	file_uri = g_file_get_uri (dst);
-
-	g_object_unref (src);
-	g_object_unref (dst);
-	close (fd);
-
-	totem_embedded_set_uri (emb, file_uri, base_uri, NULL, FALSE);
-	g_free (file_uri);
 
 	/* Schedule parsing on idle */
 	if (emb->parser_id == 0)
@@ -1177,7 +1184,7 @@ on_play_pause (GtkWidget *widget, TotemEmbedded *emb)
 }
 
 static void
-popup_menu_position_func (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, GtkWidget *button) 
+popup_menu_position_func (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, GtkWidget *button)
 {
 	GtkWidget *widget = GTK_WIDGET (button);
 	GtkRequisition menu_req;
@@ -1560,7 +1567,7 @@ on_tick (GtkWidget *bvw,
 					(int) (stream_length / 1000));
 		}
 
-		totem_time_label_set_time 
+		totem_time_label_set_time
 			(TOTEM_TIME_LABEL (emb->fs->time_label),
 			 current_time, stream_length);
 	}
@@ -1791,7 +1798,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 	g_signal_connect (G_OBJECT (emb->fs->exit_button), "clicked",
 			  G_CALLBACK (totem_embedded_on_fullscreen_exit), emb);
 
-	emb->pp_fs_button = GTK_WIDGET (gtk_tool_button_new_from_stock 
+	emb->pp_fs_button = GTK_WIDGET (gtk_tool_button_new_from_stock
 					("media-playback-start-symbolic"));
 	g_signal_connect (G_OBJECT (emb->pp_fs_button), "clicked",
 			  G_CALLBACK (on_play_pause), emb);
@@ -1804,7 +1811,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 			G_CALLBACK (totem_embedded_key_press_event), emb);
 	g_signal_connect (G_OBJECT(emb->fs_window), "key_release_event",
 			G_CALLBACK (totem_embedded_key_press_event), emb);
-	gtk_widget_add_events (GTK_WIDGET (emb->bvw), GDK_KEY_PRESS_MASK | 
+	gtk_widget_add_events (GTK_WIDGET (emb->bvw), GDK_KEY_PRESS_MASK |
 			       GDK_KEY_RELEASE_MASK);
 	g_signal_connect (G_OBJECT(emb->bvw), "key_press_event",
 			G_CALLBACK (totem_embedded_key_press_event), emb);
@@ -1869,7 +1876,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 
 	emb->volume = GTK_WIDGET (gtk_builder_get_object (emb->xml, "volume_button"));
 	gtk_scale_button_set_adjustment (GTK_SCALE_BUTTON (emb->fs->volume),
-					 gtk_scale_button_get_adjustment 
+					 gtk_scale_button_get_adjustment
 					 (GTK_SCALE_BUTTON (emb->volume)));
 	gtk_button_set_focus_on_click (GTK_BUTTON (emb->volume), FALSE);
 	g_signal_connect (G_OBJECT (emb->volume), "value-changed",
@@ -2075,7 +2082,6 @@ totem_embedded_push_parser (gpointer data)
 	TotemEmbedded *emb = (TotemEmbedded *) data;
 	TotemPlParser *parser;
 	TotemPlParserResult res;
-	GFile *file;
 
 	emb->parser_id = 0;
 
@@ -2090,9 +2096,16 @@ totem_embedded_push_parser (gpointer data)
 
 	/* Delete the temporary file created in
 	 * totem_embedded_set_playlist */
-	file = g_file_new_for_uri (emb->current_uri);
-	g_file_delete (file, NULL, NULL);
-	g_object_unref (file);
+	if (emb->remove_copy) {
+		GFile *file;
+
+		file = g_file_new_for_uri (emb->current_uri);
+		g_file_delete (file, NULL, NULL);
+		g_object_unref (file);
+
+		/* And reset */
+		emb->remove_copy = FALSE;
+	}
 
 	/* FIXME: show a proper error message */
 	switch (res) {
@@ -2150,6 +2163,7 @@ static gboolean arg_is_playlist = FALSE;
 static gboolean arg_repeat = FALSE;
 static gboolean arg_no_autostart = FALSE;
 static gboolean arg_audioonly = FALSE;
+static gboolean arg_g_fatal_warnings = FALSE;
 static TotemPluginType arg_plugin_type = TOTEM_PLUGIN_TYPE_LAST;
 
 static gboolean
@@ -2162,7 +2176,8 @@ parse_plugin_type (const gchar *option_name,
 		"gmp",
 		"narrowspace",
 		"mully",
-		"cone"
+		"cone",
+		"vegas"
 	};
 	TotemPluginType type;
 
@@ -2190,6 +2205,7 @@ static GOptionEntry option_entries [] =
 	{ TOTEM_OPTION_NOAUTOSTART, 0, 0, G_OPTION_ARG_NONE, &arg_no_autostart, NULL, NULL },
 	{ TOTEM_OPTION_AUDIOONLY, 0, 0, G_OPTION_ARG_NONE, &arg_audioonly, NULL, NULL },
         { TOTEM_OPTION_REFERRER, 0, 0, G_OPTION_ARG_STRING, &arg_referrer, NULL, NULL },
+	{ "g-fatal-warnings", 0, 0, G_OPTION_ARG_NONE, &arg_g_fatal_warnings, "Make all warnings fatal", NULL },
 	{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY /* STRING? */, &arg_remaining, NULL },
 	{ NULL }
 };
@@ -2241,7 +2257,7 @@ int main (int argc, char **argv)
 
 		env = g_getenv ("TOTEM_EMBEDDED_GDB");
 		if (env && g_ascii_strtoull (env, NULL, 10) == 1) {
-			const char *gdbargv[4];
+			const char *gdbargv[5];
 			char *gdb;
 			GError *gdberr = NULL;
 			int gdbargc = 0;
@@ -2249,6 +2265,7 @@ int main (int argc, char **argv)
 			gdb = g_strdup_printf ("gdb %s %d", argv[0], getpid ());
 
 			gdbargv[gdbargc++] = "/usr/bin/gnome-terminal";
+			gdbargv[gdbargc++] = "--disable-factory";
 			gdbargv[gdbargc++] = "-e";
 			gdbargv[gdbargc++] = gdb;
 			gdbargv[gdbargc++] = NULL;
@@ -2290,6 +2307,14 @@ int main (int argc, char **argv)
 	else
 		g_setenv("PULSE_PROP_media.role", "music", TRUE);
 
+	if (arg_g_fatal_warnings) {
+		GLogLevelFlags fatal_mask;
+
+		fatal_mask = g_log_set_always_fatal (G_LOG_FATAL_MASK);
+		fatal_mask |= G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL;
+		g_log_set_always_fatal (fatal_mask);
+	}
+
         // FIXME check that ALL necessary params were given!
 	if (arg_plugin_type == TOTEM_PLUGIN_TYPE_LAST) {
 		g_warning ("Plugin type is required\n");
@@ -2314,7 +2339,7 @@ int main (int argc, char **argv)
 	g_assert (proxy != NULL);
 
 	if (!dbus_g_proxy_call (proxy, "RequestName", &e,
-	     			G_TYPE_STRING, svcname,
+				G_TYPE_STRING, svcname,
 				G_TYPE_UINT, DBUS_NAME_FLAG_PROHIBIT_REPLACEMENT,
 				G_TYPE_INVALID,
 				G_TYPE_UINT, &res,
